@@ -365,7 +365,7 @@ extrasafe=FALSE, offset=0.05, ntrial=1000, mtd.contour=FALSE, seed=6)
           dselect[trial,] = c(99, 99);
         }else
         {
-          selcomb = select.mtd.comb(
+          selcomb = select.mtd.comb.boin(
             target, n, y, cutoff.eli, extrasafe, offset, mtd.contour =FALSE)$MTD;
           dselect[trial,1] = selcomb[1];
           dselect[trial,2] = selcomb[2];
@@ -429,6 +429,98 @@ extrasafe=FALSE, offset=0.05, ntrial=1000, mtd.contour=FALSE, seed=6)
       }
   }
 
+  ## The select.mtd.comb.boin(.) subroutine is used to get the MTD and p.est....
+  select.mtd.comb.boin <- function(target, npts, ntox, cutoff.eli=0.95, extrasafe=FALSE,
+                            offset=0.05, mtd.contour=FALSE){
+
+    y=ntox; n=npts;
+    if(nrow(n)>ncol(n) | nrow(y)>ncol(y) ) {cat("Error: npts and ntox should be arranged in a way (i.e., rotated) such that for each of them, the number of rows is less than or equal to the number of columns."); return();}
+
+    elimi=matrix(0,dim(n)[1],dim(n)[2]);
+
+	 if(extrasafe){
+        if(n[1,1]>=3) {
+            if(1-pbeta(target, y[1,1]+1, n[1,1]-y[1,1]+1)>cutoff.eli-offset) { elimi[,]=1; }
+        }
+    }
+
+    for(i in 1:dim(n)[1]){
+      for (j in 1:dim(n)[2]){
+        if(n[i,j]>=3){
+            if(1-pbeta(target, y[i,j]+1, n[i,j]-y[i,j]+1)>cutoff.eli){
+                elimi[i:dim(n)[1],j]=1; elimi[i,j:dim(n)[2]]=1; break;
+            }
+        }
+      }
+    }
+
+    if(elimi[1]==1) { selectdose=c(99, 99); selectdoses=matrix(selectdose,nrow=1)} ## no dose should be selected if the first dose is already very toxic
+    else
+    {
+      phat = (y+0.05)/(n+0.1);
+      ## perform the isotonic transformation using PAVA
+      phat=Iso::biviso(phat,n+0.1,warn=TRUE)[,];
+      phat.out=phat; phat.out[n==0]=NA;
+	    phat[elimi==1]=1.1 # to aviod selecting eliminated dose
+      ## break the ties
+      phat = phat*(n!=0)+(1E-5)*(matrix(rep(1:dim(n)[1], each = dim(n)[2],
+                                            len = length(n)),dim(n)[1],byrow=T) +
+                                   matrix(rep(1:dim(n)[2], each = dim(n)[1], len = length(n)),dim(n)[1]))
+      ## select dose closest to the target as the MTD
+      phat[n==0]=10; ## so that the dose without treating patients will not be selected
+
+      selectdose=which(abs(phat-target) == min(abs(phat-target)), arr.ind = TRUE)
+      if(length(selectdose)>2) selectdose=selectdose[1,]  ##if there are still ties, randomly pick the first one.
+
+## mtd.contour==TRUE will activate the option of multiple MTDs selection
+      aa=function(x) as.numeric(as.character(x))
+      if(mtd.contour==TRUE){
+        selectdoses = cbind('row'=1:dim(n)[1], 'col'=rep(99,dim(n)[1]))
+        for(k in dim(n)[1]:1){
+          kn = n[k,]; ky = y[k,]; kelimi = elimi[k,];
+          kphat = phat[k,]
+          if(kelimi[1]==1 || sum(n[kelimi==0])==0) {
+            kseldose=99;
+          }else{
+            adm.set = (kn!=0) & (kelimi==0);
+            adm.index = which(adm.set==T);
+            y.adm = ky[adm.set];
+            n.adm = kn[adm.set];
+            selectd = sort(abs(kphat[adm.set]-target), index.return=T)$ix[1]  ## select dose closest to the target as the MTD
+            kseldose = adm.index[selectd];
+          }
+          selectdoses[k, 2] = ifelse(is.na(kseldose), 99, kseldose)
+          if(k<dim(n)[1]) if(selectdoses[k+1,2]==dim(n)[2]) selectdoses[k,2] = dim(n)[2]
+          #if(k<dim(n)[1]) if(aa(selectdoses[k+1,2])==aa(selectdoses[k,2])) selectdoses[k,2] = 99
+		  if(k<dim(n)[1]) if(aa(selectdoses[k+1,2])==dim(n)[2] & aa(selectdoses[k+1,2])==aa(selectdoses[k,2])) selectdoses[k,2] = 99
+
+        }
+      }else{
+        selectdoses = matrix(99, nrow=1, ncol=2)
+        selectdoses[1,] = matrix(selectdose,nrow=1)
+      }
+      selectdoses = matrix(selectdoses[selectdoses[,2]!=99,],ncol=2)
+      colnames(selectdoses) = c('DoseA', 'DoseB')
+    }
+
+
+   if(mtd.contour==FALSE){
+            if(selectdoses[1,1]==99 && selectdoses[1,2]==99) {
+              ##cat("All tested doses are overly toxic. No MTD is selected! \n")
+              return(list(target=target,MTD=99,p_est=matrix(NA,nrow=dim(npts)[1],ncol=dim(npts)[2])))
+            } else{return(list(target=target,MTD=selectdoses,p_est=round(phat.out,2)))}
+
+   }else{
+            if(length(selectdoses)==0){ ##cat("All tested doses are overly toxic. No MTD is selected! \n")
+              return(list(target=target,MTD=99,p_est=matrix(NA,nrow=dim(npts)[1],ncol=dim(npts)[2])))
+            }else{
+              return(list(target=target, MTD=selectdoses,p_est=round(phat.out,2)))
+            }
+  }
+}
+
+
+
   ## The waterfall.subtrial.mtd(.) subroutine is used to get the MTD for each subtrials using the waterfall design
   waterfall.subtrial.mtd <- function(target, npts, ntox, cutoff.eli=0.95, extrasafe=FALSE, offset=0.05,temp)
   {
